==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fGetfield.h <==
// class soot.coffi.Instruction_Getfield

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 4c29f864c8f1ccd7 soot_coffi_Instruction__5fGetfield
// @dep_class d13384827121be19 soot_coffi_Instruction__5fintindex

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintindex

#include "soot/coffi/Instruction__5fintindex.h"

#ifndef _JC_soot_coffi_Instruction__5fGetfield_H_
#define _JC_soot_coffi_Instruction__5fGetfield_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fGetfield$sub_refs	_jc_soot_coffi_Instruction__5fGetfield$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fGetfield$sub_nonrefs	_jc_soot_coffi_Instruction__5fGetfield$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fGetfield$refs	_jc_soot_coffi_Instruction__5fGetfield$refs;
typedef struct _jc_soot_coffi_Instruction__5fGetfield$nonrefs	_jc_soot_coffi_Instruction__5fGetfield$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fGetfield$object	_jc_soot_coffi_Instruction__5fGetfield$object;

typedef const struct _jc_soot_coffi_Instruction__5fGetfield$vmethods	_jc_soot_coffi_Instruction__5fGetfield$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fGetfield$vtable	_jc_soot_coffi_Instruction__5fGetfield$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fGetfield$vtype	_jc_soot_coffi_Instruction__5fGetfield$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fGetfield$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fGetfield$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fGetfield$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fGetfield$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fintindex$vmethods	soot_coffi_Instruction__5fintindex;
	_jc_soot_coffi_Instruction__5fGetfield$vmethods	soot_coffi_Instruction__5fGetfield;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fGetfield$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fGetfield$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fGetfield$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fGetfield$refs {
    _jc_soot_coffi_Instruction__5fGetfield$sub_refs	soot_coffi_Instruction__5fGetfield;
    _jc_soot_coffi_Instruction__5fintindex$sub_refs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fGetfield$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fGetfield$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fintindex$sub_nonrefs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction__5fGetfield$sub_nonrefs	soot_coffi_Instruction__5fGetfield;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fGetfield$object {
	_jc_soot_coffi_Instruction__5fGetfield$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fGetfield$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fGetfield$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fGetfield$vtype _jc_soot_coffi_Instruction__5fGetfield$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fGetfield, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fGetfield$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fGetfield_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fGetfield.h <==
// class soot.coffi.Instruction_Getfield

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 4c29f864c8f1ccd7 soot_coffi_Instruction__5fGetfield
// @dep_class d13384827121be19 soot_coffi_Instruction__5fintindex

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintindex

#include "soot/coffi/Instruction__5fintindex.h"

#ifndef _JC_soot_coffi_Instruction__5fGetfield_H_
#define _JC_soot_coffi_Instruction__5fGetfield_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fGetfield$sub_refs	_jc_soot_coffi_Instruction__5fGetfield$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fGetfield$sub_nonrefs	_jc_soot_coffi_Instruction__5fGetfield$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fGetfield$refs	_jc_soot_coffi_Instruction__5fGetfield$refs;
typedef struct _jc_soot_coffi_Instruction__5fGetfield$nonrefs	_jc_soot_coffi_Instruction__5fGetfield$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fGetfield$object	_jc_soot_coffi_Instruction__5fGetfield$object;

typedef const struct _jc_soot_coffi_Instruction__5fGetfield$vmethods	_jc_soot_coffi_Instruction__5fGetfield$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fGetfield$vtable	_jc_soot_coffi_Instruction__5fGetfield$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fGetfield$vtype	_jc_soot_coffi_Instruction__5fGetfield$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fGetfield$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fGetfield$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fGetfield$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fGetfield$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fintindex$vmethods	soot_coffi_Instruction__5fintindex;
	_jc_soot_coffi_Instruction__5fGetfield$vmethods	soot_coffi_Instruction__5fGetfield;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fGetfield$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fGetfield$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fGetfield$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fGetfield$refs {
    _jc_soot_coffi_Instruction__5fGetfield$sub_refs	soot_coffi_Instruction__5fGetfield;
    _jc_soot_coffi_Instruction__5fintindex$sub_refs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fGetfield$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fGetfield$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fintindex$sub_nonrefs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction__5fGetfield$sub_nonrefs	soot_coffi_Instruction__5fGetfield;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fGetfield$object {
	_jc_soot_coffi_Instruction__5fGetfield$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fGetfield$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fGetfield$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fGetfield$vtype _jc_soot_coffi_Instruction__5fGetfield$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fGetfield, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fGetfield$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fGetfield_H_ */
